@@ -7,13 +7,17 @@
 #' permanently include a new metric in all downstream simulations, it can be included
 #' here. The function needs to be included with a name, and it must accept a metrics.input
 #' as input. If the function needs additional elements not included in that input, then
-#' the prepData function must also be revised.
+#' the prepData function must also be revised. Currently MRD references the
+#' non-abundance-weighted version of the function. This is simply so calcField knows
+#' how to handle the results downstream. Reminder to modify that function if 
+#' abundance-weighted MRD is to be implemented here.
 #'
 #' @return A list of named functions
 #'
 #' @export
 #'
 #' @importFrom picante mntd psv pse pd raoD
+#' @importFrom vegan taxondive
 #'
 #' @references Miller, E. T., D. R. Farine, and C. H. Trisos. 2016. Phylogenetic community
 #' structure metrics and null models: a review with new methods and software.
@@ -29,6 +33,7 @@ defineMetrics <- function()
 	"inter_MPD"=inter_mpd,
 	"intra_MPD"=intra_mpd,
 	"complete_MPD"=complete_mpd,
+	"VPD"=my_VPD,
 	"NAW_MNTD"=naw_mntd,
 	"AW_MNTD"=aw_mntd,
 	"PSV"=my_psv,
@@ -36,6 +41,7 @@ defineMetrics <- function()
 	"PSE"=my_pse,
 	"PD"=my_PD,
 	"PD_Cadotte"=my_PD_Cadotte,
-	"QE"=my_QE
+	"QE"=my_QE,
+	"MRD"=my_MRD
 	)
 }
